==> git-add-and-commit-0.6.2.tgz: package/lib/interactive.js <==
'use strict';

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var execSync = require('child_process').execSync;
var spawnSync = require('child_process').spawnSync;
var chalk = require('chalk');
var ansiEscapes = require('ansi-escapes');
var debounce = require('lodash.debounce');
var gitFiles = require('git-files');
var gitDiffGlob = require('git-diff-glob');
var keypress = require('terminal-keypress');
var jumper = require('terminal-jumper');
var pager = require('node-pager');

var Interactive = function () {
	function Interactive() {
		var _this = this;

		var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

		_classCallCheck(this, Interactive);

		this.options = options;
		this.fileIndex = 0;
		this.showingIndicator = false;
		this.showingDiff = false;

		this.instructions = chalk.gray('Arrow keys to navigate') + '\n' + chalk.gray('Tab to show diff of selected file(s)');
		this.gitAddPrompt = '' + chalk.green('Enter a file glob: ');

		this.onType = debounce(this.onType.bind(this), 200);
		this.onTab = this.onTab.bind(this);
		this.onArrow = this.onArrow.bind(this);
		this.exitBeforeAdd = this.exitBeforeAdd.bind(this);
		this.exitAfterAdd = this.exitAfterAdd.bind(this);

		keypress.init();
		keypress.on('exit', function () {
			return _this.showCursor();
		});
		keypress.on('exit', this.exitBeforeAdd);
	}

	_createClass(Interactive, [{
		key: 'run',
		value: function run() {
			var stagedFiles = gitFiles.staged();

			if (stagedFiles.length > 0) {
				this.showAlreadyAddedFilesWarning(stagedFiles);
			} else {
				this.showGlobPrompt();
			}
		}
	}, {
		key: 'showAlreadyAddedFilesWarning',
		value: function showAlreadyAddedFilesWarning(stagedFiles) {
			var _this2 = this;

			jumper.block('There are file(s) already staged for commit.');
			var _iteratorNormalCompletion = true;
			var _didIteratorError = false;
			var _iteratorError = undefined;

			try {
				for (var _iterator = stagedFiles[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
					var file = _step.value;

					jumper.block(chalk.red(file));
				}
			} catch (err) {
				_didIteratorError = true;
				_iteratorError = err;
			} finally {
				try {
					if (!_iteratorNormalCompletion && _iterator.return) {
						_iterator.return();
					}
				} finally {
					if (_didIteratorError) {
						throw _iteratorError;
					}
				}
			}

			jumper.break();
			jumper.block(chalk.bold('These file(s) will be committed. Continue? (y/n) '), 'warning');

			jumper.render();
			jumper.jumpTo('warning', -1);
			keypress.beginInput();

			keypress.once('return', function () {
				var answer = keypress.input();
				jumper.erase();

				if (['y', 'yes', 'Y', 'Yes'].includes(answer)) {
					jumper.reset();
					_this2.showGlobPrompt();
				} else if (['n', 'no', 'N', 'No'].includes(answer)) {
					keypress.exit();
				}
			});
		}
	}, {
		key: 'showGlobPrompt',
		value: function showGlobPrompt() {
			var _this3 = this;

			// configure keypress
			keypress.color(function (letter) {
				return chalk.red(letter);
			});
			keypress.disableBehavior('tab right left');

			// show prompt and available files
			jumper.block(this.instructions, 'instructions');
			jumper.break();
			jumper.block(this.gitAddPrompt, 'enter');
			jumper.break();
			jumper.block(chalk.green('Files found:'), 'found');
			this.renderFoundGitFiles();

			jumper.jumpTo('enter', -1);
			keypress.beginInput();

			keypress.on('keypress', this.onType);
			keypress.on('tab', this.onTab);
			keypress.on('arrow', this.onArrow);

			keypress.once('return', function () {
				_this3.showCursor();
				keypress.removeListener('keypress', _this3.onType);
				keypress.removeListener('tab', _this3.onTab);
				_this3.renderAddSuccess();
				_this3.startCommit();
			});
		}
	}, {
		key: 'onType',
		value: function onType(char, key) {
			if (['left', 'right', 'up', 'down', 'tab', 'return'].includes(key.name)) {
				return;
			}

			if (this.showingIndicator) {
				this.showCursor();
				this.fileIndex = 0;
				this.showingIndicator = false;
			}

			var glob = keypress.input();
			var coloredInput = keypress.input(true);
			jumper.find('enter').content(this.gitAddPrompt + coloredInput);

			this.renderFoundGitFiles(glob);
			jumper.jumpTo('enter', -1);
		}
	}, {
		key: 'onTab',
		value: function onTab() {
			var _this4 = this;

			if (this.showingDiff) {
				return;
			}

			this.showingDiff = true;

			var file = this.showingIndicator ? this.getIndicatedFile() : keypress.input();
			var diff = gitDiffGlob(file, {
				caseInsensitive: this.options.caseInsensitive
			});
			var pagerExitFn = function pagerExitFn() {
				return _this4.showingDiff = false;
			};

			pager(diff).then(pagerExitFn);
		}
	}, {
		key: 'onArrow',
		value: function onArrow(dir) {
			if (['left', 'right'].includes(dir)) {
				return;
			}
			if (!this.showingIndicator && dir === 'up') {
				return;
			}

			var numFiles = this.getGitFilesMatching(keypress.input()).length;

			if (numFiles < 2) {
				return;
			}

			// go to the correct file based on input direction
			if (!this.showingIndicator) {
				this.fileIndex = 0;
				this.hideCursor();
			} else if (dir === 'up') {
				this.fileIndex -= 1;
			} else if (dir === 'down') {
				this.fileIndex += 1;
			}

			// return if the index is lower than 0 or greater than the number of files
			if (this.fileIndex < 0) {
				this.fileIndex = 0;
				jumper.render();
				jumper.jumpTo('enter', -1);
				this.showCursor();
				this.showingIndicator = false;
				return;
			}
			if (this.fileIndex > numFiles - 1) {
				this.fileIndex = numFiles - 1;
				return;
			}

			// erase any previously printed indicators
			jumper.render();

			// write a file indicator on the current file line
			jumper.jumpTo('gitFile' + this.fileIndex, -1);
			process.stdout.write(ansiEscapes.cursorForward(2));
			process.stdout.write(chalk.bold.blue('⬅'));

			this.showingIndicator = true;
		}
	}, {
		key: 'showCursor',
		value: function showCursor() {
			process.stdout.write(ansiEscapes.cursorShow);
		}
	}, {
		key: 'hideCursor',
		value: function hideCursor() {
			process.stdout.write(ansiEscapes.cursorHide);
		}
	}, {
		key: 'getIndicatedFile',
		value: function getIndicatedFile() {
			var currentLine = jumper.find('gitFile' + this.fileIndex).escapedText;
			return currentLine.trim().split(' ')[1];
		}
	}, {
		key: 'renderAddSuccess',
		value: function renderAddSuccess() {
			// if the indicator is showing, only add that specific file.
			// otherwise, add all files matching the given glob
			if (this.showingIndicator) {
				this.addFiles = [this.getIndicatedFile()];
			} else {
				var glob = keypress.input();
				this.addFiles = this.getGitFilesMatching(glob);
			}

			jumper.reset();

			jumper.block(chalk.green('Added files:'), 'found');
			for (var i = 0; i < this.addFiles.length; i++) {
				var file = this.addFiles[i];
				var id = 'addedFile' + i;
				jumper.block(chalk.red(file) + '  ' + chalk.green('✓'), id);
			}
			jumper.break();
			jumper.block('---------------------------------------------');
			jumper.break();
			jumper.block(chalk.green('Enter commit message: "'), 'commit');
			jumper.render();

			jumper.jumpTo('commit', -1);
			process.stdout.write(chalk.green('"'));
			jumper.jumpTo('commit', -1);
		}
	}, {
		key: 'startCommit',
		value: function startCommit() {
			var _this5 = this;

			keypress.color(function (letter) {
				return chalk.green(letter);
			});
			keypress.beginInput();

			var onKeypress = function onKeypress() {
				process.stdout.write('' + chalk.green('"'));
				process.stdout.write(ansiEscapes.cursorBackward(1));
			};
			keypress.on('keypress', onKeypress);

			keypress.once('return', function () {
				keypress.removeListener('keypress', onKeypress);
				_this5.commitMessage = keypress.input();

				var content = jumper.find('commit').text;
				content = '' + content + keypress.input(true) + chalk.green('"');
				jumper.find('commit').content(content);
				_this5.commit();
				_this5.complete();
			});

			keypress.removeListener('exit', this.exitBeforeAdd);
			keypress.on('exit', this.exitAfterAdd);
		}
	}, {
		key: 'commit',
		value: function commit() {
			var _iteratorNormalCompletion2 = true;
			var _didIteratorError2 = false;
			var _iteratorError2 = undefined;

			try {
				for (var _iterator2 = this.addFiles[Symbol.iterator](), _step2; !(_iteratorNormalCompletion2 = (_step2 = _iterator2.next()).done); _iteratorNormalCompletion2 = true) {
					var file = _step2.value;

					execSync('git add ' + file);
				}
			} catch (err) {
				_didIteratorError2 = true;
				_iteratorError2 = err;
			} finally {
				try {
					if (!_iteratorNormalCompletion2 && _iterator2.return) {
						_iterator2.return();
					}
				} finally {
					if (_didIteratorError2) {
						throw _iteratorError2;
					}
				}
			}

			execSync('git commit -m "' + this.commitMessage + '"');

			keypress.removeListener('exit', this.exitAfterAdd);
		}
	}, {
		key: 'complete',
		value: function complete() {
			jumper.break();
			jumper.block('---------------------------------------------');
			jumper.break();
			jumper.block('Files committed successfully.');
			jumper.render();

			keypress.exit();
		}
	}, {
		key: 'renderFoundGitFiles',
		value: function renderFoundGitFiles() {
			var glob = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';

			// remove previous search
			jumper.removeAllMatching(/gitFile\d+/);

			var i = this.options.caseInsensitive ? 'i' : '';

			var allMatches = {
				untracked: gitFiles.untracked('relative').filter(function (file) {
					return new RegExp(glob, i).test(file);
				}),
				modified: gitFiles.modified('relative').filter(function (file) {
					return new RegExp(glob, i).test(file);
				}),
				deleted: gitFiles.deleted('relative').filter(function (file) {
					return new RegExp(glob, i).test(file);
				})
			};

			var counter = 0;

			var _iteratorNormalCompletion3 = true;
			var _didIteratorError3 = false;
			var _iteratorError3 = undefined;

			try {
				for (var _iterator3 = Object.keys(allMatches)[Symbol.iterator](), _step3; !(_iteratorNormalCompletion3 = (_step3 = _iterator3.next()).done); _iteratorNormalCompletion3 = true) {
					var group = _step3.value;
					var _iteratorNormalCompletion4 = true;
					var _didIteratorError4 = false;
					var _iteratorError4 = undefined;

					try {
						for (var _iterator4 = allMatches[group][Symbol.iterator](), _step4; !(_iteratorNormalCompletion4 = (_step4 = _iterator4.next()).done); _iteratorNormalCompletion4 = true) {
							var file = _step4.value;

							var text = '  ' + chalk.bold.gray('(' + group + ')') + ' ' + chalk.red(file);
							jumper.block(text, 'gitFile' + counter);
							counter += 1;
						}
					} catch (err) {
						_didIteratorError4 = true;
						_iteratorError4 = err;
					} finally {
						try {
							if (!_iteratorNormalCompletion4 && _iterator4.return) {
								_iterator4.return();
							}
						} finally {
							if (_didIteratorError4) {
								throw _iteratorError4;
							}
						}
					}
				}
			} catch (err) {
				_didIteratorError3 = true;
				_iteratorError3 = err;
			} finally {
				try {
					if (!_iteratorNormalCompletion3 && _iterator3.return) {
						_iterator3.return();
					}
				} finally {
					if (_didIteratorError3) {
						throw _iteratorError3;
					}
				}
			}

			jumper.render();
		}
	}, {
		key: 'getGitFilesMatching',
		value: function getGitFilesMatching(glob) {
			var files = gitFiles.all('relative').sort();
			var regex = new RegExp(glob, 'i');
			return files.filter(function (file) {
				return regex.test(file);
			});
		}
	}, {
		key: 'exitBeforeAdd',
		value: function exitBeforeAdd() {
			jumper.erase();
		}
	}, {
		key: 'exitAfterAdd',
		value: function exitAfterAdd() {
			process.stdout.write(ansiEscapes.cursorSavePosition);

			for (var i = 0; i < this.addFiles.length; i++) {
				var id = 'addedFile' + i;
				jumper.jumpTo(id, -2);
				process.stdout.write(chalk.red('✗'));
			}

			process.stdout.write(ansiEscapes.cursorRestorePosition);
			console.log();
			console.log();
			console.log('Aborting -- no files added.');
		}
	}]);

	return Interactive;
}();

module.exports = Interactive;

==> git-add-and-commit-1.0.0.tgz: package/lib/interactive.js <==
'use strict';

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var execSync = require('child_process').execSync;
var spawnSync = require('child_process').spawnSync;
var chalk = require('chalk');
var ansiEscapes = require('ansi-escapes');
var debounce = require('lodash.debounce');
var gitFiles = require('git-files');
var gitDiffGlob = require('git-diff-glob');
var keypress = require('terminal-keypress');
var jumper = require('terminal-jumper');
var pager = require('node-pager');

var Interactive = function () {
	function Interactive() {
		var _this = this;

		var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

		_classCallCheck(this, Interactive);

		this.options = options;
		this.fileIndex = 0;
		this.showingIndicator = false;
		this.showingDiff = false;

		this.instructions = chalk.gray('Arrow keys to navigate') + '\n' + chalk.gray('Tab to show diff of selected file(s)');
		this.gitAddPrompt = '' + chalk.green('Enter a file glob: ');

		this.onType = debounce(this.onType.bind(this), 200);
		this.onTab = this.onTab.bind(this);
		this.onArrow = this.onArrow.bind(this);
		this.exitBeforeAdd = this.exitBeforeAdd.bind(this);
		this.exitAfterAdd = this.exitAfterAdd.bind(this);

		keypress.init();
		keypress.on('exit', function () {
			return _this.showCursor();
		});
		keypress.on('exit', this.exitBeforeAdd);
	}

	_createClass(Interactive, [{
		key: 'run',
		value: function run() {
			var stagedFiles = gitFiles.staged();

			if (stagedFiles.length > 0) {
				this.showAlreadyAddedFilesWarning(stagedFiles);
			} else {
				this.showGlobPrompt();
			}
		}
	}, {
		key: 'showAlreadyAddedFilesWarning',
		value: function showAlreadyAddedFilesWarning(stagedFiles) {
			var _this2 = this;

			jumper.block('There are file(s) already staged for commit.');
			var _iteratorNormalCompletion = true;
			var _didIteratorError = false;
			var _iteratorError = undefined;

			try {
				for (var _iterator = stagedFiles[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
					var file = _step.value;

					jumper.block(chalk.red(file));
				}
			} catch (err) {
				_didIteratorError = true;
				_iteratorError = err;
			} finally {
				try {
					if (!_iteratorNormalCompletion && _iterator.return) {
						_iterator.return();
					}
				} finally {
					if (_didIteratorError) {
						throw _iteratorError;
					}
				}
			}

			jumper.break();
			jumper.block(chalk.bold('These file(s) will be committed. Continue? (y/n) '), 'warning');

			jumper.render();
			jumper.jumpTo('warning', -1);
			keypress.beginInput();

			keypress.once('return', function () {
				var answer = keypress.input();
				jumper.erase();

				if (['y', 'yes', 'Y', 'Yes'].includes(answer)) {
					jumper.reset();
					_this2.showGlobPrompt();
				} else if (['n', 'no', 'N', 'No'].includes(answer)) {
					keypress.exit();
				}
			});
		}
	}, {
		key: 'showGlobPrompt',
		value: function showGlobPrompt() {
			var _this3 = this;

			// configure keypress
			keypress.color(function (letter) {
				return chalk.red(letter);
			});
			keypress.disableBehavior('tab right left');

			// show prompt and available files
			jumper.block(this.instructions, 'instructions');
			jumper.break();
			jumper.block(this.gitAddPrompt, 'enter');
			jumper.break();
			jumper.block(chalk.green('Files found:'), 'found');
			this.renderFoundGitFiles();

			jumper.jumpTo('enter', -1);
			keypress.beginInput();

			keypress.on('keypress', this.onType);
			keypress.on('tab', this.onTab);
			keypress.on('arrow', this.onArrow);

			keypress.once('return', function () {
				_this3.showCursor();
				keypress.removeListener('keypress', _this3.onType);
				keypress.removeListener('tab', _this3.onTab);
				_this3.renderAddSuccess();
				_this3.startCommit();
			});
		}
	}, {
		key: 'onType',
		value: function onType(char, key) {
			if (['left', 'right', 'up', 'down', 'tab', 'return'].includes(key.name)) {
				return;
			}

			if (this.showingIndicator) {
				this.showCursor();
				this.fileIndex = 0;
				this.showingIndicator = false;
			}

			var glob = keypress.input();
			var coloredInput = keypress.input(true);
			jumper.find('enter').content(this.gitAddPrompt + coloredInput);

			this.renderFoundGitFiles(glob);
			jumper.jumpTo('enter', -1);
		}
	}, {
		key: 'onTab',
		value: function onTab() {
			var _this4 = this;

			if (this.showingDiff) {
				return;
			}

			this.showingDiff = true;

			var file = this.showingIndicator ? this.getIndicatedFile() : keypress.input();
			var diff = gitDiffGlob(file, {
				caseSensitive: this.options.caseSensitive
			});
			var pagerExitFn = function pagerExitFn() {
				return _this4.showingDiff = false;
			};

			pager(diff).then(pagerExitFn);
		}
	}, {
		key: 'onArrow',
		value: function onArrow(dir) {
			if (['left', 'right'].includes(dir)) {
				return;
			}
			if (!this.showingIndicator && dir === 'up') {
				return;
			}

			var numFiles = this.getGitFilesMatching(keypress.input()).length;

			if (numFiles < 2) {
				return;
			}

			// go to the correct file based on input direction
			if (!this.showingIndicator) {
				this.fileIndex = 0;
				this.hideCursor();
			} else if (dir === 'up') {
				this.fileIndex -= 1;
			} else if (dir === 'down') {
				this.fileIndex += 1;
			}

			// return if the index is lower than 0 or greater than the number of files
			if (this.fileIndex < 0) {
				this.fileIndex = 0;
				jumper.render();
				jumper.jumpTo('enter', -1);
				this.showCursor();
				this.showingIndicator = false;
				return;
			}
			if (this.fileIndex > numFiles - 1) {
				this.fileIndex = numFiles - 1;
				return;
			}

			// erase any previously printed indicators
			jumper.render();

			// write a file indicator on the current file line
			jumper.jumpTo('gitFile' + this.fileIndex, -1);
			process.stdout.write(ansiEscapes.cursorForward(2));
			process.stdout.write(chalk.bold.blue('⬅'));

			this.showingIndicator = true;
		}
	}, {
		key: 'showCursor',
		value: function showCursor() {
			process.stdout.write(ansiEscapes.cursorShow);
		}
	}, {
		key: 'hideCursor',
		value: function hideCursor() {
			process.stdout.write(ansiEscapes.cursorHide);
		}
	}, {
		key: 'getIndicatedFile',
		value: function getIndicatedFile() {
			var currentLine = jumper.find('gitFile' + this.fileIndex).escapedText;
			return currentLine.trim().split(' ')[1];
		}
	}, {
		key: 'renderAddSuccess',
		value: function renderAddSuccess() {
			// if the indicator is showing, only add that specific file.
			// otherwise, add all files matching the given glob
			if (this.showingIndicator) {
				this.addFiles = [this.getIndicatedFile()];
			} else {
				var glob = keypress.input();
				this.addFiles = this.getGitFilesMatching(glob);
			}

			jumper.reset();

			jumper.block(chalk.green('Added files:'), 'found');
			for (var i = 0; i < this.addFiles.length; i++) {
				var file = this.addFiles[i];
				var id = 'addedFile' + i;
				jumper.block(chalk.red(file) + '  ' + chalk.green('✓'), id);
			}
			jumper.break();
			jumper.block('---------------------------------------------');
			jumper.break();
			jumper.block(chalk.green('Enter commit message: "'), 'commit');
			jumper.render();

			jumper.jumpTo('commit', -1);
			process.stdout.write(chalk.green('"'));
			jumper.jumpTo('commit', -1);
		}
	}, {
		key: 'startCommit',
		value: function startCommit() {
			var _this5 = this;

			keypress.color(function (letter) {
				return chalk.green(letter);
			});
			keypress.beginInput();

			var onKeypress = function onKeypress() {
				process.stdout.write('' + chalk.green('"'));
				process.stdout.write(ansiEscapes.cursorBackward(1));
			};
			keypress.on('keypress', onKeypress);

			keypress.once('return', function () {
				keypress.removeListener('keypress', onKeypress);
				_this5.commitMessage = keypress.input();

				var content = jumper.find('commit').text;
				content = '' + content + keypress.input(true) + chalk.green('"');
				jumper.find('commit').content(content);
				_this5.commit();
				_this5.complete();
			});

			keypress.removeListener('exit', this.exitBeforeAdd);
			keypress.on('exit', this.exitAfterAdd);
		}
	}, {
		key: 'commit',
		value: function commit() {
			var _iteratorNormalCompletion2 = true;
			var _didIteratorError2 = false;
			var _iteratorError2 = undefined;

			try {
				for (var _iterator2 = this.addFiles[Symbol.iterator](), _step2; !(_iteratorNormalCompletion2 = (_step2 = _iterator2.next()).done); _iteratorNormalCompletion2 = true) {
					var file = _step2.value;

					execSync('git add ' + file);
				}
			} catch (err) {
				_didIteratorError2 = true;
				_iteratorError2 = err;
			} finally {
				try {
					if (!_iteratorNormalCompletion2 && _iterator2.return) {
						_iterator2.return();
					}
				} finally {
					if (_didIteratorError2) {
						throw _iteratorError2;
					}
				}
			}

			execSync('git commit -m "' + this.commitMessage + '"');

			keypress.removeListener('exit', this.exitAfterAdd);
		}
	}, {
		key: 'complete',
		value: function complete() {
			jumper.break();
			jumper.block('---------------------------------------------');
			jumper.break();
			jumper.block('Files committed successfully.');
			jumper.render();

			keypress.exit();
		}
	}, {
		key: 'renderFoundGitFiles',
		value: function renderFoundGitFiles() {
			var glob = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';

			// remove previous search
			jumper.removeAllMatching(/gitFile\d+/);

			var i = this.options.caseSensitive ? '' : 'i';

			var allMatches = {
				modified: gitFiles.modified('relative').filter(function (file) {
					return new RegExp(glob, i).test(file);
				}),
				deleted: gitFiles.deleted('relative').filter(function (file) {
					return new RegExp(glob, i).test(file);
				}),
				untracked: gitFiles.untracked('relative').filter(function (file) {
					return new RegExp(glob, i).test(file);
				})
			};

			var counter = 0;

			var _iteratorNormalCompletion3 = true;
			var _didIteratorError3 = false;
			var _iteratorError3 = undefined;

			try {
				for (var _iterator3 = Object.keys(allMatches)[Symbol.iterator](), _step3; !(_iteratorNormalCompletion3 = (_step3 = _iterator3.next()).done); _iteratorNormalCompletion3 = true) {
					var group = _step3.value;
					var _iteratorNormalCompletion4 = true;
					var _didIteratorError4 = false;
					var _iteratorError4 = undefined;

					try {
						for (var _iterator4 = allMatches[group][Symbol.iterator](), _step4; !(_iteratorNormalCompletion4 = (_step4 = _iterator4.next()).done); _iteratorNormalCompletion4 = true) {
							var file = _step4.value;

							var text = '  ' + chalk.bold.gray('(' + group + ')') + ' ' + chalk.red(file);
							jumper.block(text, 'gitFile' + counter);
							counter += 1;
						}
					} catch (err) {
						_didIteratorError4 = true;
						_iteratorError4 = err;
					} finally {
						try {
							if (!_iteratorNormalCompletion4 && _iterator4.return) {
								_iterator4.return();
							}
						} finally {
							if (_didIteratorError4) {
								throw _iteratorError4;
							}
						}
					}
				}
			} catch (err) {
				_didIteratorError3 = true;
				_iteratorError3 = err;
			} finally {
				try {
					if (!_iteratorNormalCompletion3 && _iterator3.return) {
						_iterator3.return();
					}
				} finally {
					if (_didIteratorError3) {
						throw _iteratorError3;
					}
				}
			}

			jumper.render();
		}
	}, {
		key: 'getGitFilesMatching',
		value: function getGitFilesMatching(glob) {
			var files = gitFiles.all('relative').sort();
			var regex = new RegExp(glob, 'i');
			return files.filter(function (file) {
				return regex.test(file);
			});
		}
	}, {
		key: 'exitBeforeAdd',
		value: function exitBeforeAdd() {
			jumper.erase();
		}
	}, {
		key: 'exitAfterAdd',
		value: function exitAfterAdd() {
			process.stdout.write(ansiEscapes.cursorSavePosition);

			for (var i = 0; i < this.addFiles.length; i++) {
				var id = 'addedFile' + i;
				jumper.jumpTo(id, -2);
				process.stdout.write(chalk.red('✗'));
			}

			process.stdout.write(ansiEscapes.cursorRestorePosition);
			console.log();
			console.log();
			console.log('Aborting -- no files added.');
		}
	}]);

	return Interactive;
}();

module.exports = Interactive;
